==> nextcloud-app-spreed-1%3A8.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/lb.js <==
OC.L10N.register(
    "spreed",
    {
    "Save changes" : "Ännerunge späicheren",
    "None" : "Keng",
    "User" : "User",
    "Disabled" : "Deaktivéiert",
    "Users" : "Benotzer",
    "Name" : "Numm",
    "Saved" : "Gespäichert",
    "Copy link" : "Link kopéieren",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Contacts" : "Kontakter",
    "Loading" : "Loading",
    "Groups" : "Gruppen",
    "Error" : "Fehler",
    "Password protect" : "Passwuertgeschützt",
    "Back" : "Zeréck",
    "Close" : "Zoumaachen",
    "Reply" : "Äntwerten",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "guest" : "Gaascht",
    "Settings" : "Astellungen",
    "Edit" : "Änneren",
    "Dismiss" : "Ofbriechen",
    "Share link" : "Link deelen",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
    "Password" : "Passwuert",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Copied!" : "Kopéiert!",
    "Not supported!" : "Nët ennerstëtzt!",
    "Press ⌘-C to copy." : "Dréck ⌘-C fir ze kopéieren.",
    "Press Ctrl-C to copy." : "Dréck CTRL-C fir ze kopéieren.",
    "Cancel" : "Ofbriechen",
    "Change password" : "Passwuert änneren",
    "Rename" : "Ëmbenennen",
    "Send" : "Schécken",
    "Share" : "Deelen",
    "Error while sharing" : "Feeler beim Deelen",
    "Favorited" : "Favoriséiert"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A9.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/lb.js <==
OC.L10N.register(
    "spreed",
    {
    "Save changes" : "Ännerunge späicheren",
    "None" : "Keng",
    "User" : "User",
    "Disabled" : "Deaktivéiert",
    "Users" : "Benotzer",
    "Name" : "Numm",
    "Saved" : "Gespäichert",
    "Copy link" : "Link kopéieren",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Gruppen",
    "Error" : "Fehler",
    "Password protect" : "Passwuertgeschützt",
    "Back" : "Zeréck",
    "Close" : "Zoumaachen",
    "Reply" : "Äntwerten",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "guest" : "Gaascht",
    "Add users or groups" : "Add users or groups",
    "Settings" : "Astellungen",
    "Edit" : "Änneren",
    "Dismiss" : "Ofbriechen",
    "Share link" : "Link deelen",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
    "Password" : "Passwuert",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Copied!" : "Kopéiert!",
    "Not supported!" : "Nët ennerstëtzt!",
    "Press ⌘-C to copy." : "Dréck ⌘-C fir ze kopéieren.",
    "Press Ctrl-C to copy." : "Dréck CTRL-C fir ze kopéieren.",
    "Cancel" : "Ofbriechen",
    "Change password" : "Passwuert änneren",
    "Rename" : "Ëmbenennen",
    "Send" : "Schécken",
    "Share" : "Deelen",
    "Error while sharing" : "Feeler beim Deelen",
    "Favorited" : "Favoriséiert",
    "Contacts" : "Kontakter"
},
"nplurals=2; plural=(n != 1);");
